<?php

namespace Service;

use Doctrine\ORM\EntityManager;
use Util\InstanceProvider;
use Factory\CommentType as CommentTypeFactory;

class CommentType
{

    private $entityManager;
    private $environment;

    /** @var  \Factory\CommentType $commentTypeFactory */
    protected $commentTypeFactory;

    /**
     * TaskTracking constructor.
     * @param EntityManager $entityManager
     */
    public function __construct(EntityManager $entityManager, CommentTypeFactory $commentTypeFactory)
    {
        $this->environment = InstanceProvider::getEnvironment();
        $this->entityManager = $entityManager;
        $this->commentTypeFactory = $commentTypeFactory;
    }

    public function findCommentType()
    {
        return InstanceProvider::getRepository()->getLocalCommentType()->findCommentType($this->environment->getCurrentOrganizationId());
    }

    public function saveCommentType($id, $name, $control, $attachmentRequired, $commentDescription)
    {
        $connection = $this->entityManager->getConnection();
        try {
            $this->entityManager->beginTransaction();
            $organizationId = $this->environment->getCurrentOrganizationId();
            $commentType = InstanceProvider::getRepository()->getCommentType()->findOneBy(array('id' => $id));
            $commentType = $this->commentTypeFactory->saveCommentType(
                $commentType,
                $name,
                $control,
                $attachmentRequired,
                $organizationId,
                $commentDescription
            );
            $this->entityManager->persist($commentType);
            $this->entityManager->flush();
            $connection->commit();
        } catch (\Exception $e) {
            $connection->rollBack();
            throw $e;
        }
    }

    public function removeCommentType($id)
    {
        $connection = $this->entityManager->getConnection();
        try {
            $connection->beginTransaction();
            $commentType = InstanceProvider::getRepository()->getCommentType()->findOneBy(array('id' => $id));
            $this->entityManager->remove($commentType);

            $this->entityManager->flush();
            $connection->commit();
        } catch (\Exception $e) {
            $connection->rollBack();
            throw $e;
        }
    }
}
