/******************************************************************************/
/* Agent2B                                                                    */
/*                                                                            */
/******************************************************************************/
/*                                                                            */
/* Nome: 0204_GERSTP_AVALIA_AUDITORIA                                         */
/*                                                                            */
/* Descrio:                                                                 */
/*   Aplica os Critrios de Avaliao Parcial e Final considerando as         */
/*   inspees realizadas em uma Auditoria                                    */
/*                                                                            */
/*                                                                            */
/* Criao:                                                                   */
/*   29/01/2002 - Adriano de Arajo                                           */
/*                                                                            */
/******************************************************************************/

/******************************************************************************/
/* @C:\WIN_PRJ\SQL\ORACLE\0204_GERSTP_AVALIA_AUDITORIA.SQL                    */
/******************************************************************************/

CREATE OR REPLACE PROCEDURE AVALIA_AUDITORA
  (P_CDFILIAL    IN AUDITORIA.CDFILIAL%TYPE,
   P_NRAUDITORIA IN AUDITORIA.NRAUDITORIA%TYPE) IS

V_CDTIPORESU    CRITAVAPARCI.CDTIPORESU%TYPE;
V_CDINSPECAO    INSPECAO.CDINSPECAO%TYPE;
V_CDTIPORESUFIN CRITAVAFINAL.CDTIPORESU%TYPE;
V_CDCRITAVAFIN  CRITAVAFINAL.CDCRITAVAFIN%TYPE;
V_QTDIAVALQUAL  CRITAVAFINAL.QTDIAVALQUAL%TYPE;
V_CDQUALIF      CRITAVAFINAL.CDQUALIF%TYPE;

BEGIN
  FOR C_TOTGRINSPEC IN
    (SELECT
      AUDITORIA.CDTIPAUDIT,
      INSPECAO.CDARVINSPEC,
      SUM(NVL(RESPOSINSPEC.VRPONTRESINS, 0)) AS VRTOTGRINSPEC
    FROM
      AUDITORIA,
      RESPOSINSPEC,
      ITEMINSAUDIT,
      INSPECAUDIT,
      INSPECAO
    WHERE
      AUDITORIA.CDFILIAL        = P_CDFILIAL                 AND
      AUDITORIA.NRAUDITORIA     = P_NRAUDITORIA              AND
      ITEMINSAUDIT.CDFILIAL     = AUDITORIA.CDFILIAL         AND
      ITEMINSAUDIT.NRAUDITORIA  = AUDITORIA.NRAUDITORIA      AND
      ITEMINSAUDIT.CDINSPECAO   = RESPOSINSPEC.CDINSPECAO    AND
      ITEMINSAUDIT.CDRESPINSPEC = RESPOSINSPEC.CDRESPINSPEC  AND

      ITEMINSAUDIT.CDFILIAL     = INSPECAUDIT.CDFILIAL       AND
      ITEMINSAUDIT.NRAUDITORIA  = INSPECAUDIT.NRAUDITORIA    AND
      ITEMINSAUDIT.NRINSPECAUDI = INSPECAUDIT.NRINSPECAUDI   AND

      INSPECAUDIT.CDINSPECAO    = INSPECAO.CDINSPECAO
    GROUP BY
      AUDITORIA.CDTIPAUDIT,
      INSPECAO.CDARVINSPEC)
  LOOP
     SELECT
       MAX(CDINSPECAO) INTO V_CDINSPECAO
     FROM
       INSPECAO
     WHERE
       CDARVINSPEC = C_TOTGRINSPEC.CDARVINSPEC;

     V_CDTIPORESU := NULL;
     SELECT
       MAX(CRITAVAPARCI.CDTIPORESU) INTO V_CDTIPORESU
     FROM
       CRITAVAPARCI
     WHERE
       CRITAVAPARCI.CDTIPAUDIT   = C_TOTGRINSPEC.CDTIPAUDIT AND
       CRITAVAPARCI.CDINSPECAO   = V_CDINSPECAO             AND
       CRITAVAPARCI.IDFAIXAVPARC = '='                      AND
       C_TOTGRINSPEC.VRTOTGRINSPEC BETWEEN VRINIFAIXAVP AND VRFINFAIXAVP;

     IF V_CDTIPORESU IS NULL THEN
       SELECT
         MAX(CRITAVAPARCI.CDTIPORESU) INTO V_CDTIPORESU
       FROM
         CRITAVAPARCI
       WHERE
         CRITAVAPARCI.CDTIPAUDIT   = C_TOTGRINSPEC.CDTIPAUDIT AND
         CRITAVAPARCI.CDINSPECAO   = V_CDINSPECAO             AND
         CRITAVAPARCI.IDFAIXAVPARC = '>'                      AND
         C_TOTGRINSPEC.VRTOTGRINSPEC >= VRINIFAIXAVP;
     END IF;

     IF V_CDTIPORESU IS NULL THEN
       SELECT
         MAX(CRITAVAPARCI.CDTIPORESU) INTO V_CDTIPORESU
       FROM
         CRITAVAPARCI
       WHERE
         CRITAVAPARCI.CDTIPAUDIT   = C_TOTGRINSPEC.CDTIPAUDIT AND
         CRITAVAPARCI.CDINSPECAO   = V_CDINSPECAO             AND
         CRITAVAPARCI.IDFAIXAVPARC = '<'                      AND
         C_TOTGRINSPEC.VRTOTGRINSPEC <= VRINIFAIXAVP;
     END IF;

     UPDATE INSPECAUDIT
     SET CDTIPORESU = V_CDTIPORESU
     WHERE
       CDFILIAL    = P_CDFILIAL    AND
       NRAUDITORIA = P_NRAUDITORIA AND
       CDINSPECAO  = V_CDINSPECAO;
  END LOOP;

  V_CDTIPORESUFIN := NULL;
  V_CDCRITAVAFIN  := NULL;
  V_CDQUALIF      := NULL;
  V_QTDIAVALQUAL  := 0;
  SELECT
     MAX(CRITAVAFINAL.CDTIPORESU),
     MAX(CRITAVAFINAL.CDCRITAVAFIN),
     MAX(CRITAVAFINAL.QTDIAVALQUAL),
     MAX(CRITAVAFINAL.CDQUALIF) INTO V_CDTIPORESUFIN,
                                  V_CDCRITAVAFIN,
                                  V_QTDIAVALQUAL,
                                  V_CDQUALIF
  FROM
     AUDITORIA,
     INSPECAUDIT,
     INSPAVAFINAL,
     CRITAVAFINAL
  WHERE
    AUDITORIA.CDFILIAL        = P_CDFILIAL               AND
    AUDITORIA.NRAUDITORIA     = P_NRAUDITORIA            AND
    INSPECAUDIT.CDFILIAL      = AUDITORIA.CDFILIAL       AND
    INSPECAUDIT.NRAUDITORIA   = AUDITORIA.NRAUDITORIA    AND
    CRITAVAFINAL.CDTIPAUDIT   = AUDITORIA.CDTIPAUDIT     AND
    INSPAVAFINAL.CDTIPAUDIT   = AUDITORIA.CDTIPAUDIT     AND
    INSPAVAFINAL.CDINSPECAO   = INSPECAUDIT.CDINSPECAO   AND
    INSPAVAFINAL.CDTIPORESU   = INSPECAUDIT.CDTIPORESU   AND
    INSPAVAFINAL.CDCRITAVAFIN = CRITAVAFINAL.CDCRITAVAFIN;

  UPDATE AUDITORIA
  SET
    CDTIPORESU   = V_CDTIPORESUFIN,
    CDCRITAVAFIN = V_CDCRITAVAFIN
  WHERE
    CDFILIAL     = P_CDFILIAL    AND
    NRAUDITORIA  = P_NRAUDITORIA;

  IF V_CDQUALIF IS NOT NULL THEN
    UPDATE FORNECEDOR
    SET CDQUALIF    = V_CDQUALIF,
        DTVALQUALIF = TO_DATE(SYSDATE) + V_QTDIAVALQUAL
    WHERE
      CDFORNECED =
         (SELECT
            CDFORNECED
          FROM
            AUDITORIA
          WHERE
            CDFILIAL    = P_CDFILIAL AND
            NRAUDITORIA = P_NRAUDITORIA);
  END IF;
END;
/
